#! /usr/bin/env python
import os
from os.path import expandvars
from I3Tray import *

import sys,getopt

ucrprogram = "/home/mase/work/I3/SIMULATION/V02-00-12/build/bin/ucr-icetray-ucr"
infile = "DAT000003_"
outfile = "corsika.i3.gz"

runnum = 10

if len(sys.argv) > 1:
    infile = sys.argv[1]
if len(sys.argv) > 2:
    outfile = sys.argv[2]
if len(sys.argv) > 3:
    runnum = sys.argv[3]
        

load("libicetray")
load("libdataclasses")
load("libphys-services")
load("libsimclasses")
load("libucr-icetray")
load("libdataio")
load("libc2j-icetray")
load("libmmc-icetray")
#load("libsim-prod")
load("libamanda-core")
load("libsim-services")
load("libI3Db")
load("libcoordinate-service")
load("libicepick")


tray = I3Tray()
tray.AddService("I3JavaVMFactory","javavm")(
    ("options",["-Djava.class.path=/home/mase/work/I3/SIMULATION/V02-00-12/build/lib/mmc.jar"]),
    )

tray.AddService("I3ReaderServiceFactory","reader")(
    ("omitevent",True),
    ("filename","/net/local/icecube/i3tools/RHEL4-x86_64/test-data/sim/GCD.i3.gz"),
    )

tray.AddService("I3XMLSummaryServiceFactory","summary")(
    ("outputfilename","corsika.000000.000000.summary.xml"),
    )

photonics = expandvars("$I3_WORK")
tray.AddService("I3MCTimeGeneratorServiceFactory","time-gen")(
    ("Year",2007),
    ("DAQTime",173357040000000000)
    )

tray.AddService("I3SPRNGRandomServiceFactory","sprngrandom")(
    ("NStreams",500),
    ("Seed",1234),
    ("StreamNum",runnum),
    )

tray.AddModule("I3Muxer","muxer")(
    ("detectorstatusservice","I3DetectorStatusService"),
    ("eventservice","I3EventService"),
    ("geometryservice","I3GeometryService"),
    ("calibrationservice","I3CalibrationService"),
    )

tray.AddModule("I3EventCounter","counter3")(
    ("physicscountername","Generated Events"),
    )

tray.AddModule("I3GeneratorUCR","corsika")(
    ("eventstoissue",100),
    ("ucropts", ucrprogram+" "+ infile+ " -oms -rphi -run=" + `runnum` + " -over=1 -SHOWERS=100 -FLUXSUM=0.131475115 -LENGTH=1760 -RADIUS=880 -DEPTH=1950 -HEIGHT=2834 -EARTHR=6.4e6 -cutfe=1000. -curved=1 -tr=2"),
    )

tray.AddModule("I3CorsikaWeightModule","corsikaweight")(
    ("energyprimarymin",1.E6*I3Units.GeV),
    ("energyprimarymax",1.E11*I3Units.GeV),
    ("cylinderlength",1760*I3Units.meter),
    ("spectrumtype",0),
    ("nevents",100),
    ("fluxsum",0.131475115),
    ("cylinderradius",880*I3Units.meter),
    )

tray.AddModule("I3PropagatorMMC","propagate")(
    ("mode",-1),
    ("opts","-seed=1 -radius=880 -length=1760"),
    )

tray.AddModule("I3Writer","writer")(
    ("filename", outfile),
    ("skipkeys",["FrameIndex","NKGInfo"]),
    ("streams",["Physics"])
   )

tray.AddModule("TrashCan","trashcan")
    

tray.Execute(10000000)
tray.Finish()
    
